// Define the COVID-19 data
const data = {
  name: 'ASD Traits',
  children: [
    {
      name: 'YES',
      value: 5,
      level: '#2a0e57',
      children: [
        {
          name: 'White European',
          children: [
            {
              name: 'Male',
              children: [
                {
                  name: 'Jaundice - Yes',
                  value: 2,
                  level: '#3a9f7e',
                },
                {
                  name: 'Jaundice - No',
                  value: 6,
                  level: '#3a9f7e',
                },
              ],
            },
            {
              name: 'Female',
              children: [
                {
                  name: 'Jaundice - Yes',
                  value: 4,
                  level: '#3a9f7e',
                },
                {
                  name: 'Jaundice - No',
                  value: 6,
                  level: '#3a9f7e',
                },
              ],
            },
          ],
        },
        {
          name: 'Hispanic',
          children: [
            {
              name: 'Male',
              children: [
                {
                  name: 'Jaundice - Yes',
                  value: 3,
                  level: '#3a9f7e',
                },
                {
                  name: 'Jaundice - No',
                  value: 7,
                  level: '#3a9f7e',
                },
              ],
            },
            {
              name: 'Female',
              children: [
                {
                  name: 'Jaundice - Yes',
                  value: 2,
                  level: '#3a9f7e',
                },
                {
                  name: 'Jaundice - No',
                  value: 8,
                  level: '#3a9f7e',
                },
              ],
            },
          ],
        },
        {
          name: 'Asian',
          children: [
            {
              name: 'Male',
              children: [
                {
                  name: 'Jaundice - Yes',
                  value: 3,
                  level: '#3a9f7e',
                },
                {
                  name: 'Jaundice - No',
                  value: 5,
                  level: '#3a9f7e',
                },
              ],
            },
            {
              name: 'Female',
              children: [
                {
                  name: 'Jaundice - Yes',
                  value: 2,
                  level: '#3a9f7e',
                },
                {
                  name: 'Jaundice - No',
                  value: 7,
                  level: '#3a9f7e',
                },
              ],
            },
          ],
        },
      ],
    },
    {
      name: 'NO',
      value: 8,
      level: '#2a0e57',
      children: [
        {
          name: 'White European',
          children: [
            {
              name: 'Male',
              children: [
                {
                  name: 'Jaundice - Yes',
                  value: 1,
                  level: '#3a9f7e',
                },
                {
                  name: 'Jaundice - No',
                  value: 4,
                  level: '#3a9f7e',
                },
              ],
            },
            {
              name: 'Female',
              children: [
                {
                  name: 'Jaundice - Yes',
                  value: 2,
                  level: '#3a9f7e',
                },
                {
                  name: 'Jaundice - No',
                  value: 3,
                  level: '#3a9f7e',
                },
              ],
            },
          ],
        },
        {
          name: 'Hispanic',
          children: [
            {
              name: 'Male',
              children: [
                {
                  name: 'Jaundice - Yes',
                  value: 2,
                  level: '#3a9f7e',
                },
                {
                  name: 'Jaundice - No',
                  value: 4,
                  level: '#3a9f7e',
                },
              ],
            },
            {
              name: 'Female',
              children: [
                {
                  name: 'Jaundice - Yes',
                  value: 2,
                  level: '#3a9f7e',
                },
                {
                  name: 'Jaundice - No',
                  value: 4,
                  level: '#3a9f7e',
                },
              ],
            },
          ],
        },
        {
          name: 'Asian',
          children: [
            {
              name: 'Male',
              children: [
                {
                  name: 'Jaundice - Yes',
                  value: 2,
                  level: '#3a9f7e',
                },
                {
                  name: 'Jaundice - No',
                  value: 5,
                  level: '#3a9f7e',
                },
              ],
            },
            {
              name: 'Female',
              children: [
                {
                  name: 'Jaundice - Yes',
                  value: 2,
                  level: '#3a9f7e',
                },
                {
                  name: 'Jaundice - No',
                  value: 2,
                  level: '#3a9f7e',
                },
              ],
            },
          ],
        },
      ],
    },
  ],
};

// Define width, height, and margin of the tree
const margin = {
  top: 10,
  right: 250,
  bottom: 200,
  left: 200,
};
const width = 850 - margin.left - margin.right;
const height = 650 - margin.top - margin.bottom;

const tree = d3.tree().size([height, width]);

// Assign hierarchical structure to classify the data
let nodes = d3.hierarchy(data, (node) => node.children);

// Provide data connection for nodes to their respective position in the tree
nodes = tree(nodes);

// Check if SVG already exists
const svgExists = d3.select('svg').empty();


if (svgExists) {
  const svg = d3
    .select('body')
    .append('svg')
    .attr('width', width + margin.left + margin.right)
    .attr('height', height + margin.top + margin.bottom);
  const g = svg
    .append('g') // appends group
    .attr(
      'transform',
      'translate(' + margin.left + ',' + margin.top + ')',
    );

  // Define links between nodes
  const link = g
    .selectAll('.link')
    .data(nodes.descendants().slice(1))
    .enter()
    .append('path')
    .attr('class', 'link')
    .style('stroke', (d) => d.data.level)
    .attr('d', (d) => {
      return (
        'M' +
        d.y +
        ',' +
        d.x +
        'C' +
        (d.y + d.parent.y) / 2 +
        ',' +
        d.x +
        ' ' +
        (d.y + d.parent.y) / 2 +
        ',' +
        d.parent.x +
        ' ' +
        d.parent.y +
        ',' +
        d.parent.x
      );
    });

  // Declare a group for each node present in the tree
  const node = g
    .selectAll('.node')
    .data(nodes.descendants())
    .enter()
    .append('g')
    .attr(
      'class',
      (d) =>
        'node' +
        (d.children ? ' node--internal' : ' node--leaf'),
    )
    .attr(
      'transform',
      (d) => 'translate(' + d.y + ',' + d.x + ')',
    );

  // Define shape of the node
  node
    .append('circle')
    .attr('r', (d) => d.data.value)
    .style('stroke', (d) => d.data.type)
    .style('fill', (d) => d.data.level);

  // Add a new node to the list
  node
    .append('text')
    .attr('dy', '.60em')
    .attr('x', (d) =>
      d.children
        ? (d.data.value + 5) * -1
        : d.data.value + 5,
    )
    .attr('y', (d) =>
      d.children && d.depth !== 0 ? -(d.data.value + 5) : d,
    )
    .style('text-anchor', (d) =>
      d.children ? 'end' : 'start',
    )
    .text((d) => d.data.name);

  /*node
    .append('circle')
    .attr('r', 10) // set a fixed radius for all circles
    .style('fill', 'lightsteelblue');

  node
    .append('text')
    .attr('dy', '0.35em')
    .attr('x', (d) => (d.children ? -13 : 13))
    .style('text-anchor', (d) =>
      d.children ? 'end' : 'start',
    )
    .text((d) => d.data.name); */
}
